/**
 * 
 */
package com.example.layouttest.presenter;

import javax.annotation.PostConstruct;

import com.example.layouttest.Browser;
import com.example.layouttest.event.TourDetailsSelectedEvent;
import com.example.layouttest.view.CityBuilderView;
import com.example.layouttest.view.CityBuilderViewImpl;
import com.vaadin.data.Item;
import com.vaadin.data.util.HierarchicalContainer;
import com.vaadin.event.EventRouter;
import com.vaadin.ui.Panel;

@SuppressWarnings("serial")
public class CityBuilderPresenter 
    extends AbstractPresenter<CityBuilderView, CityBuilderView.Presenter> 
    implements CityBuilderView.Presenter {

    EventRouter eventBus;
    private CityEditorPresenter cityEditorPresenter;
    private TourEditorPresenter tourEditorPresenter; 

    public void setCityEditorPresenter(CityEditorPresenter cityEditorPresenter) {
        this.cityEditorPresenter = cityEditorPresenter;
    }

    public void setTourEditorPresenter(TourEditorPresenter tourEditorPresenter) {
        this.tourEditorPresenter = tourEditorPresenter;
    }
    
    public CityBuilderPresenter(EventRouter eventBus) {
    	this.eventBus = eventBus;
    	init();
    }

    @PostConstruct
    void init() {        
    }
    
    @Override
    protected CityBuilderView createView() {
        return new CityBuilderViewImpl();
    } 
    
    @Override
    public void go(Panel panel) {
        HierarchicalContainer citiesContainer = fetchCities();
        getView().setCities(citiesContainer);
        showCityEditor();
        panel.setContent(getView().asLayout());
    }

    @Override
    public void onItemSelected(String selectedItemId) {
        if (selectedItemId.equals("CITY")) {
            showCityEditor();
        } else {
            showTourEditor();
        }
    }

    @Override
    public void onNewCityClicked() {
        showCityEditor();               
    }     
    
    @Override
    public void onNewTourClicked(String cityItemId) {
    	showTourEditor();
    }
    
    @Override
    public void onTourDetails(String tourItemId) {
        eventBus.fireEvent(new TourDetailsSelectedEvent(tourItemId));
    }

    HierarchicalContainer fetchCities() {
        HierarchicalContainer citiesContainer = new HierarchicalContainer();
        citiesContainer.addContainerProperty(Browser.PID_NAME, String.class, null);
        String cityItemId = "CITY";
        Item cityItem = citiesContainer.addItem(cityItemId);
        cityItem.getItemProperty(Browser.PID_NAME).setValue(cityItemId);

        String tourItemId = "TOUR";
        Item tourItem = citiesContainer.addItem(tourItemId);
        tourItem.getItemProperty(Browser.PID_NAME).setValue(tourItemId);
        
        citiesContainer.setParent(tourItemId, cityItemId);
        citiesContainer.setChildrenAllowed(tourItemId, false);

        
        return citiesContainer;
    }


    private void showCityEditor() {
        cityEditorPresenter.go(getView().getEditorPanel());
    }
    
    private void showTourEditor() {
        tourEditorPresenter.go(getView().getEditorPanel());
    }
}
